<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class GetLeads_Banner_Slider_Widget extends Widget_Base {

    public function get_name() {
        return 'getleads-banner-slider';
    }

    public function get_title() {
        return esc_html__( 'GetLeads Banner Slider', 'getleads' );
    }

    public function get_icon() {
        return 'eicon-post-slider';
    }

    public function get_categories() {
        return [ 'getleads-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
			'banner_slider_content_section',
			[
				'label' => __( 'Banner Slider', 'getleads' ),
			]
        );

        $this->add_control(
			'banner_slider_animation_tigger',
			[
				'label' => __( 'Disable Slider Animation?', 'getleads' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Enable', 'getleads' ),
				'label_off' => __( 'Disable', 'getleads' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

        $banner_slider = new Repeater();

        $banner_slider->add_control(
			'banner_slider_image',
			[
				'label' => __( 'Banner Image', 'getleads' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$banner_slider->add_control(
			'banner_slider_list_title', [
				'label' => __( 'Title', 'getleads' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Live your Power' , 'getleads' ),
				'label_block' => true,
			]
		);

		$banner_slider->add_control(
			'banner_slider_list_content', [
				'label' => __( 'Content', 'getleads' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'List Content' , 'getleads' ),
				'show_label' => false,
			]
        );


        $banner_slider->start_controls_tabs(
            'banner_double_button_control_tab'
        );

        // -------------------- Button One
        $banner_slider->start_controls_tab(
            'banner_button_control_one_tab',
            [
                'label' => esc_html__( 'Button One', 'getleads' ),
            ]
        );

        $banner_slider->add_control(
			'button_one_title',
			[
				'label' => __( 'Button One Title', 'getleads' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'WATCH THE VIDEO', 'getleads' ),
                'placeholder' => __( 'Type your title here', 'getleads' ),
                'label_block' => true,
			]
		);

        $banner_slider->add_control(
			'button_one_link',
			[
				'label' => __( 'Link', 'getleads' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'getleads' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

        $banner_slider->end_controls_tab();

        $banner_slider->start_controls_tab(
            'banner_button_control_two_tab',
            [
                'label' => esc_html__( 'Button Two', 'getleads' ),
            ]
        );

        $banner_slider->add_control(
			'button_two_title',
			[
				'label' => __( 'Button Two Title', 'getleads' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'GET YOUR FREE WEEK', 'getleads' ),
                'placeholder' => __( 'Type your title here', 'getleads' ),
                'label_block' => true,
			]
		);

        $banner_slider->add_control(
			'button_two_link',
			[
				'label' => __( 'Link', 'getleads' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'getleads' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
        );

        $banner_slider->end_controls_tab();

        $banner_slider->end_controls_tabs();

		$this->add_control(
			'banner_slider_lists',
			[
				'label' => __( 'Lists', 'getleads' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $banner_slider->get_controls(),
				'default' => [
					[
						'banner_slider_list_title' => __( 'Live your Power', 'getleads' ),
						'banner_slider_list_content' => __( 'At GetLeads Yoga something amazing is happening. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Delectus voluptates perspiciatis deleniti commodi quaerat, aut, cum eos incidunt labore ipsam dolore quae.', 'getleads' ),
                        'button_one_title' => __( 'WATCH THE VIDEO', 'getleads' ),
                        'button_two_title' => __( 'GET YOUR FREE WEEK', 'getleads' ),
					],
					[
						'banner_slider_list_title' => __( 'Happiness is an Inside Job', 'getleads' ),
						'banner_slider_list_content' => __( 'At GetLeads Yoga something amazing is happening. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Delectus voluptates perspiciatis deleniti commodi quaerat, aut, cum eos incidunt labore ipsam dolore quae.', 'getleads' ),
                        'button_one_title' => __( 'VIEW CLASSES', 'getleads' ),
					],
					[
                        'banner_slider_list_title' => __( 'Less is the New More', 'getleads' ),
						'banner_slider_list_content' => __( 'At GetLeads Yoga something amazing is happening. Lorem ipsum dolor sit amet, consectetur adipisicing elit. Delectus voluptates perspiciatis deleniti commodi quaerat, aut, cum eos incidunt labore ipsam dolore quae.', 'getleads' ),
                        'button_one_title' => __( 'SEE TIMETABLE', 'getleads' ),
                        'button_two_title' => __( 'MEET OUR TEACHERS', 'getleads' ),
					],
				],
				'title_field' => '{{{ banner_slider_list_title }}}',
			]
		);

        $this->end_controls_section();

        // ------------ Style Tab Strat --------------

        // ------------ Banner Container ------------------
        $this->start_controls_section(
			'banner_container_style_control',
			[
				'label' => __( 'Container', 'getleads' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'banner_container_height',
			[
				'label' => __( 'Height', 'getleads' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 500,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .banner-content' => 'min-height: {{SIZE}}{{UNIT}};',
				],
			]
        );

        $this->add_responsive_control(
			'banner_overlay_color',
			[
				'label' => __( 'Overlay Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-overlay' => 'background-color: {{VALUE}}',
				],
			]
        );

		$this->end_controls_section();

        // ------------ Content --------------
        $this->start_controls_section(
			'banner_content_section',
			[
				'label' => __( 'Content', 'getleads' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        // ------------ Title
        $this->add_control(
			'banner_content_heading_one',
			[
				'label' => __( 'Title', 'getleads' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'banner_title_color',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-slider-title' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'banner_title_content_typography',
				'label' => __( 'Typography', 'getleads' ),
				'selector' => '{{WRAPPER}} .banner-slider-title',
			]
		);

        $this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'banner_title_text_shadow',
				'label' => __( 'Text Shadow', 'getleads' ),
				'selector' => '{{WRAPPER}} .banner-slider-title',
			]
        );

        // ------------ Content
        $this->add_control(
			'banner_content_heading_two',
			[
				'label' => __( 'Content', 'getleads' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
        );

        $this->add_responsive_control(
			'banner_content_color',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-slider-content' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'banner_content_typography',
				'label' => __( 'Typography', 'getleads' ),
				'selector' => '{{WRAPPER}} .banner-slider-content',
			]
		);

        $this->end_controls_section();

        // ------------ Button ------------------
        $this->start_controls_section(
			'banner_button_content_section',
			[
				'label' => __( 'Button', 'getleads' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs(
            'banner_double_button_style_control_tab'
        );

        // -------------------- Button One
        $this->start_controls_tab(
            'banner_button_style_one_tab',
            [
                'label' => esc_html__( 'Button One', 'getleads' ),
            ]
        );

        // ------------ Button Normal
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'banner_button_one_typography',
				'label' => __( 'Typography', 'getleads' ),
				'selector' => '{{WRAPPER}} .btn-primary',
			]
        );

        $this->add_control(
			'banner_button_one_color',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-primary' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'banner_button_one_background',
			[
				'label' => __( 'Background Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-primary' => 'backgroud-color: {{VALUE}}',
					'{{WRAPPER}} .btn-primary' => 'border-color: {{VALUE}}',
				],
			]
        );

        // ------------ Button Hover

        $this->add_control(
			'banner_button_heading_one',
			[
				'label' => __( 'Hover', 'getleads' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
        );

        $this->add_control(
			'banner_button_one_color_hover',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-primary:hover' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'banner_button_one_bg_color_hover',
			[
				'label' => __( 'Background', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-primary:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .btn-primary:hover' => 'border-color: {{VALUE}}',
				],
			]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'banner_button_style_two_tab',
            [
                'label' => esc_html__( 'Button Two', 'getleads' ),
            ]
        );

        // ------------ Button Normal
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'banner_button_two_typography',
				'label' => __( 'Typography', 'getleads' ),
				'selector' => '{{WRAPPER}} .btn-outline-light',
			]
        );

        $this->add_control(
			'banner_button_two_color',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-outline-light' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'banner_button_two_background',
			[
				'label' => __( 'Background Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-outline-light' => 'backgroud-color: {{VALUE}}',
					'{{WRAPPER}} .btn-outline-light' => 'border-color: {{VALUE}}',
				],
			]
        );

        // ------------ Button Hover

        $this->add_control(
			'banner_button_heading_two',
			[
				'label' => __( 'Hover', 'getleads' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
        );

        $this->add_control(
			'banner_button_two_color_hover',
			[
				'label' => __( 'Color', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-outline-light:hover' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'banner_button_two_bg_color_hover',
			[
				'label' => __( 'Background', 'getleads' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .btn-outline-light:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .btn-outline-light:hover' => 'border-color: {{VALUE}}',
				],
			]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

		$this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings_for_display();

        extract($settings);
        ?>
        <div class="swiper-container banner-slider <?php echo esc_attr( "yes" === $banner_slider_animation_tigger ? "banner-animation" : "" ); ?>">
            <div class="swiper-wrapper">
            <?php
                if (is_array($banner_slider_lists)) {
                    foreach ($banner_slider_lists as $key => $banner_slider_list) {
                        ?>
                        <div class="swiper-slide">
                            <div class="banner-content"  style="background-image:url(<?php echo esc_attr( $banner_slider_list['banner_slider_image']['url'] ); ?>)">
                                <div class="banner-overlay"></div>
                                <div class="container">
                                    <div class="row">
                                        <div class="col-lg-8">
                                            <?php if ("" !== $banner_slider_list['banner_slider_list_title']) { ?>
                                            <div class="animate-two">
                                                <h2 class="banner-slider-title"><?php echo esc_html( $banner_slider_list['banner_slider_list_title'] ); ?></h2>
                                            </div>
                                            <!-- /banner-slider-title -->
                                            <?php }; ?>

                                            <?php if ("" !== $banner_slider_list['banner_slider_list_content']) { ?>
                                            <div class="banner-slider-content animate-three">
                                                <?php echo getleads_kses($banner_slider_list['banner_slider_list_content']); ?>
                                            </div>
                                            <!-- /banner-slider-content -->
                                            <?php }; ?>

                                            <?php if ("" !== $banner_slider_list['button_one_title'] ||  "" !== $banner_slider_list['button_two_title'] ) { ?>
                                            <div class="animate-four banner-button-wraper">
                                                <?php if ( "" !== $banner_slider_list['button_one_title'] ) { ?>
                                                <a href="<?php echo esc_url( $banner_slider_list['button_one_link']['url'] ); ?>" target="<?php echo esc_attr( $banner_slider_list['button_one_link']['is_external'] ? "_blank" : "_slef" )?>"  rel="<?php echo esc_attr( $banner_slider_list['button_one_link']['nofollow'] ? "nofollow" : "" )?>" class="btn btn-primary"><?php echo esc_html( $banner_slider_list['button_one_title'] ); ?></a>
                                                <?php }; ?>

                                                <?php if ( "" !== $banner_slider_list['button_two_title'] ) { ?>
                                                <a href="<?php echo esc_url( $banner_slider_list['button_two_link']['url'] ); ?>" target="<?php echo esc_attr( $banner_slider_list['button_two_link']['is_external'] ? "_blank" : "_slef" )?>"  rel="<?php echo esc_attr( $banner_slider_list['button_two_link']['nofollow'] ? "nofollow" : "" )?>" class="btn btn-outline-light"><?php echo esc_html( $banner_slider_list['button_two_title'] ); ?></a>
                                                <?php }; ?>
                                            </div>
                                            <!-- /banner slider button -->
                                            <?php }; ?>
                                        </div>
                                        <!-- /col-lg-8 -->
                                    </div>
                                </div>
                                <!-- /container -->
                            </div>
                            <!-- /banner-content -->
                        </div>
                        <!-- /swiper-slide -->
                        <?php
                    }
                }
            ?>
            </div>
            <!-- /swiper wraper -->
            <!-- Add Pagination -->
            <div class="swiper-pagination"></div>
        </div>
        <!-- /banner-slider -->
        <?php
    }

    protected function content_template() { }
}